The simplest possible time tracker:

- press Enter on window or mouse click Play button to start session

- press Enter or mouse click Stop button to end session

Optionally task description may be entered. Autocompletion will make suggestions from previous task.

To see stats for the last two days, press Ctrl-H

---
Note 1:

Intentionally time duration is combined all over the each single hour for each task name, then total amount rounded up to 10min.

E.g.:
- three sessions by 1 min each calculates as 10min
- two sessions by 7 min each and one 1min calculates as 20min

---
Note 2: 

Hour activity ended is one that counts.

E.g.:

- session started 17:57 ended 18:51

In report you'll have "18h - 10min"
---

To quit, press Ctrl-Q
